<?php
/**
 * Title: Posts heading
 * Slug: twentytwentyfour/hidden-posts-heading
 * Categories: hidden
 * Inserter: no
 */
?>
<!-- wp:heading {"level":1,"align":"wide","style":{"spacing":{"padding":{"top":"var:preset|spacing|50"}}}} -->
<h1 class="wp-block-heading alignwide" style="padding-top:var(--wp--preset--spacing--50)"><?php esc_html_e( 'Posts', 'twentytwentyfour' ); ?></h1>
<!-- /wp:heading -->
